==> blancoNLpackGenerator-0.0.95-src.zip: src/blanco/xliff/util/task/BlancoXliffUtilChangeBatchProcess.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.xliff.util.task;

import java.io.IOException;

import blanco.xliff.util.task.valueobject.BlancoXliffUtilChangeProcessInput;

/**
 * ob`NX [BlancoXliffUtilChangeBatchProcess]B
 *
 *
 * ob`̌ĂяoB
 * <code>
 * java -classpath (NXpX) blanco.xliff.util.task.BlancoXliffUtilChangeBatchProcess -help
 * </code>
 */
public class BlancoXliffUtilChangeBatchProcess {
    /**
     * IB
     */
    public static final int END_SUCCESS = 0;

    /**
     * ُ͈IBIjava.lang.IllegalArgumentExceptionꍇB
     */
    public static final int END_ILLEGAL_ARGUMENT_EXCEPTION = 7;

    /**
     * o͗OIBIjava.io.IOExceptionꍇB
     */
    public static final int END_IO_EXCEPTION = 8;

    /**
     * ُIBob`̏JnɎsꍇAѓIjava.lang.Error܂java.lang.RuntimeExceptionꍇB
     */
    public static final int END_ERROR = 9;

    /**
     * R}hCsꂽۂ̃Gg|CgłB
     *
     * @param args R\[pꂽB
     */
    public static final void main(final String[] args) {
        final BlancoXliffUtilChangeBatchProcess batchProcess = new BlancoXliffUtilChangeBatchProcess();

        // ob`̈B
        final BlancoXliffUtilChangeProcessInput input = new BlancoXliffUtilChangeProcessInput();

        boolean isNeedUsage = false;
        boolean isFieldTargetfileProcessed = false;
        boolean isFieldSourcefileProcessed = false;

        // R}hC̉͂Ȃ܂B
        for (int index = 0; index < args.length; index++) {
            String arg = args[index];
            if (arg.startsWith("-verbose=")) {
                input.setVerbose(Boolean.valueOf(arg.substring(9)).booleanValue());
            } else if (arg.startsWith("-targetfile=")) {
                input.setTargetfile(arg.substring(12));
                isFieldTargetfileProcessed = true;
            } else if (arg.startsWith("-sourcefile=")) {
                input.setSourcefile(arg.substring(12));
                isFieldSourcefileProcessed = true;
            } else if (arg.startsWith("-settargetifnotexist=")) {
                input.setSettargetifnotexist(Boolean.valueOf(arg.substring(21)).booleanValue());
            } else if (arg.equals("-?") || arg.equals("-help")) {
                usage();
                System.exit(END_SUCCESS);
            } else {
                System.out.println("BlancoXliffUtilChangeBatchProcess: ̓p[^[" + arg + "]͖܂B");
                isNeedUsage = true;
            }
        }

        if (isNeedUsage) {
            usage();
        }

        if( isFieldTargetfileProcessed == false) {
            System.out.println("BlancoXliffUtilChangeBatchProcess: JnsB̓p[^[input]̕K{tB[hl[targetfile]ɒlݒ肳Ă܂B");
            System.exit(END_ILLEGAL_ARGUMENT_EXCEPTION);
        }
        if( isFieldSourcefileProcessed == false) {
            System.out.println("BlancoXliffUtilChangeBatchProcess: JnsB̓p[^[input]̕K{tB[hl[sourcefile]ɒlݒ肳Ă܂B");
            System.exit(END_ILLEGAL_ARGUMENT_EXCEPTION);
        }

        int retCode = batchProcess.execute(input);

        // IR[h߂܂B
        // ӁFSystem.exit()ĂяoĂ_ɒӂĂB
        System.exit(retCode);
    }

    /**
     * ̓Iȃob`eLq邽߂̃\bhłB
     *
     * ̃\bhɎۂ̏eLq܂B
     *
     * @param input ob`̓̓p[^B
     * @return ob`̏IR[hBEND_SUCCESS, END_ILLEGAL_ARGUMENT_EXCEPTION, END_IO_EXCEPTION, END_ERROR ̂ꂩ̒l߂܂B
     * @throws IOException o͗OꍇB
     * @throws IllegalArgumentException ͒lɕsꍇB
     */
    public int process(final BlancoXliffUtilChangeProcessInput input) throws IOException, IllegalArgumentException {
        // ̓p[^`FbN܂B
        validateInput(input);

        // ̉ӏŃRpCG[ꍇABlancoXliffUtilChangeProcessC^tF[X blanco.xliff.util.taskpbP[W BlancoXliffUtilChangeProcessImplNX쐬邱Ƃɂłꍇ܂B
        final BlancoXliffUtilChangeProcess process = new BlancoXliffUtilChangeProcessImpl();

        // ̖{̂s܂B
        final int retCode = process.execute(input);

        return retCode;
    }

    /**
     * NXCX^Xăob`sۂ̃Gg|CgłB
     *
     * ̃\bh͉L̎dl񋟂܂B
     * <ul>
     * <li>\bh̓̓p[^̓e`FbNB
     * <li>IllegalArgumentException, RuntimeException, ErrorȂǂ̗OcatchĖ߂lւƕϊB
     * </ul>
     *
     * @param input ob`̓̓p[^B
     * @return ob`̏IR[hBEND_SUCCESS, END_ILLEGAL_ARGUMENT_EXCEPTION, END_IO_EXCEPTION, END_ERROR ̂ꂩ̒l߂܂B
     * @throws IllegalArgumentException ͒lɕsꍇB
     */
    public final int execute(final BlancoXliffUtilChangeProcessInput input) throws IllegalArgumentException {
        try {
            // ob`̖{̂s܂B
            int retCode = process(input);

            return retCode;
        } catch (IllegalArgumentException ex) {
            System.out.println("BlancoXliffUtilChangeBatchProcess: ͗O܂Bob`𒆒f܂B:" + ex.toString());
            // ُ͈IB
            return END_ILLEGAL_ARGUMENT_EXCEPTION;
        } catch (IOException ex) {
            System.out.println("BlancoXliffUtilChangeBatchProcess: o͗O܂Bob`𒆒f܂B:" + ex.toString());
            // ُ͈IB
            return END_IO_EXCEPTION;
        } catch (RuntimeException ex) {
            System.out.println("BlancoXliffUtilChangeBatchProcess: ^CO܂Bob`𒆒f܂B:" + ex.toString());
            ex.printStackTrace();
            // ُIB
            return END_ERROR;
        } catch (Error er) {
            System.out.println("BlancoXliffUtilChangeBatchProcess: ^CG[܂Bob`𒆒f܂B:" + er.toString());
            er.printStackTrace();
            // ُIB
            return END_ERROR;
        }
    }

    /**
     * ̃ob`NX̎g̐Wo͂Ɏ߂̃\bhłB
     */
    public static final void usage() {
        System.out.println("BlancoXliffUtilChangeBatchProcess: Usage:");
        System.out.println("  java blanco.xliff.util.task.BlancoXliffUtilChangeBatchProcess -verbose=l1 -targetfile=l2 -sourcefile=l3 -settargetifnotexist=l4");
        System.out.println("    -verbose");
        System.out.println("      [verbose[hœ삳邩ǂB]");
        System.out.println("      ^[^U]");
        System.out.println("      ftHgl[false]");
        System.out.println("    -targetfile");
        System.out.println("      [o͑Ώۂ XLIFF (*.xlf) t@C]");
        System.out.println("      ^[]");
        System.out.println("      K{p[^");
        System.out.println("    -sourcefile");
        System.out.println("      [͑Ώۂ XLIFF (*.xlf) t@CB]");
        System.out.println("      ^[]");
        System.out.println("      K{p[^");
        System.out.println("    -settargetifnotexist");
        System.out.println("      [target ꍇ target Zbg邩ǂB]");
        System.out.println("      ^[^U]");
        System.out.println("      ftHgl[false]");
        System.out.println("    -? , -help");
        System.out.println("      [g\܂B]");
    }

    /**
     * ̃ob`NX̓̓p[^̑Ó`FbN{邽߂̃\bhłB
     *
     * @param input ob`̓̓p[^B
     * @throws IllegalArgumentException ͒lɕsꍇB
     */
    public void validateInput(final BlancoXliffUtilChangeProcessInput input) throws IllegalArgumentException {
        if (input == null) {
            throw new IllegalArgumentException("BlancoBatchProcessBatchProcess: JnsB̓p[^[input]null^܂B");
        }
        if (input.getTargetfile() == null) {
            throw new IllegalArgumentException("BlancoXliffUtilChangeBatchProcess: JnsB̓p[^[input]̕K{tB[hl[targetfile]ɒlݒ肳Ă܂B");
        }
        if (input.getSourcefile() == null) {
            throw new IllegalArgumentException("BlancoXliffUtilChangeBatchProcess: JnsB̓p[^[input]̕K{tB[hl[sourcefile]ɒlݒ肳Ă܂B");
        }
    }
}

==> blancoNLpackGenerator-0.0.97-src.zip: src/blanco/xliff/util/task/BlancoXliffUtilChangeBatchProcess.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.xliff.util.task;

import java.io.IOException;

import blanco.xliff.util.task.valueobject.BlancoXliffUtilChangeProcessInput;

/**
 * ob`NX [BlancoXliffUtilChangeBatchProcess]B
 *
 *
 * ob`̌ĂяoB
 * <code>
 * java -classpath (NXpX) blanco.xliff.util.task.BlancoXliffUtilChangeBatchProcess -help
 * </code>
 */
public class BlancoXliffUtilChangeBatchProcess {
    /**
     * IB
     */
    public static final int END_SUCCESS = 0;

    /**
     * ُ͈IBIjava.lang.IllegalArgumentExceptionꍇB
     */
    public static final int END_ILLEGAL_ARGUMENT_EXCEPTION = 7;

    /**
     * o͗OIBIjava.io.IOExceptionꍇB
     */
    public static final int END_IO_EXCEPTION = 8;

    /**
     * ُIBob`̏JnɎsꍇAѓIjava.lang.Error܂java.lang.RuntimeExceptionꍇB
     */
    public static final int END_ERROR = 9;

    /**
     * R}hCsꂽۂ̃Gg|CgłB
     *
     * @param args R\[pꂽB
     */
    public static final void main(final String[] args) {
        final BlancoXliffUtilChangeBatchProcess batchProcess = new BlancoXliffUtilChangeBatchProcess();

        // ob`̈B
        final BlancoXliffUtilChangeProcessInput input = new BlancoXliffUtilChangeProcessInput();

        boolean isNeedUsage = false;
        boolean isFieldXliffdirProcessed = false;

        // R}hC̉͂Ȃ܂B
        for (int index = 0; index < args.length; index++) {
            String arg = args[index];
            if (arg.startsWith("-verbose=")) {
                input.setVerbose(Boolean.valueOf(arg.substring(9)).booleanValue());
            } else if (arg.startsWith("-xliffdir=")) {
                input.setXliffdir(arg.substring(10));
                isFieldXliffdirProcessed = true;
            } else if (arg.startsWith("-settargetifnotexist=")) {
                input.setSettargetifnotexist(Boolean.valueOf(arg.substring(21)).booleanValue());
            } else if (arg.equals("-?") || arg.equals("-help")) {
                usage();
                System.exit(END_SUCCESS);
            } else {
                System.out.println("BlancoXliffUtilChangeBatchProcess: ̓p[^[" + arg + "]͖܂B");
                isNeedUsage = true;
            }
        }

        if (isNeedUsage) {
            usage();
        }

        if( isFieldXliffdirProcessed == false) {
            System.out.println("BlancoXliffUtilChangeBatchProcess: JnsB̓p[^[input]̕K{tB[hl[xliffdir]ɒlݒ肳Ă܂B");
            System.exit(END_ILLEGAL_ARGUMENT_EXCEPTION);
        }

        int retCode = batchProcess.execute(input);

        // IR[h߂܂B
        // ӁFSystem.exit()ĂяoĂ_ɒӂĂB
        System.exit(retCode);
    }

    /**
     * ̓Iȃob`eLq邽߂̃\bhłB
     *
     * ̃\bhɎۂ̏eLq܂B
     *
     * @param input ob`̓̓p[^B
     * @return ob`̏IR[hBEND_SUCCESS, END_ILLEGAL_ARGUMENT_EXCEPTION, END_IO_EXCEPTION, END_ERROR ̂ꂩ̒l߂܂B
     * @throws IOException o͗OꍇB
     * @throws IllegalArgumentException ͒lɕsꍇB
     */
    public int process(final BlancoXliffUtilChangeProcessInput input) throws IOException, IllegalArgumentException {
        // ̓p[^`FbN܂B
        validateInput(input);

        // ̉ӏŃRpCG[ꍇABlancoXliffUtilChangeProcessC^tF[X blanco.xliff.util.taskpbP[W BlancoXliffUtilChangeProcessImplNX쐬邱Ƃɂłꍇ܂B
        final BlancoXliffUtilChangeProcess process = new BlancoXliffUtilChangeProcessImpl();

        // ̖{̂s܂B
        final int retCode = process.execute(input);

        return retCode;
    }

    /**
     * NXCX^Xăob`sۂ̃Gg|CgłB
     *
     * ̃\bh͉L̎dl񋟂܂B
     * <ul>
     * <li>\bh̓̓p[^̓e`FbNB
     * <li>IllegalArgumentException, RuntimeException, ErrorȂǂ̗OcatchĖ߂lւƕϊB
     * </ul>
     *
     * @param input ob`̓̓p[^B
     * @return ob`̏IR[hBEND_SUCCESS, END_ILLEGAL_ARGUMENT_EXCEPTION, END_IO_EXCEPTION, END_ERROR ̂ꂩ̒l߂܂B
     * @throws IllegalArgumentException ͒lɕsꍇB
     */
    public final int execute(final BlancoXliffUtilChangeProcessInput input) throws IllegalArgumentException {
        try {
            // ob`̖{̂s܂B
            int retCode = process(input);

            return retCode;
        } catch (IllegalArgumentException ex) {
            System.out.println("BlancoXliffUtilChangeBatchProcess: ͗O܂Bob`𒆒f܂B:" + ex.toString());
            // ُ͈IB
            return END_ILLEGAL_ARGUMENT_EXCEPTION;
        } catch (IOException ex) {
            System.out.println("BlancoXliffUtilChangeBatchProcess: o͗O܂Bob`𒆒f܂B:" + ex.toString());
            // ُ͈IB
            return END_IO_EXCEPTION;
        } catch (RuntimeException ex) {
            System.out.println("BlancoXliffUtilChangeBatchProcess: ^CO܂Bob`𒆒f܂B:" + ex.toString());
            ex.printStackTrace();
            // ُIB
            return END_ERROR;
        } catch (Error er) {
            System.out.println("BlancoXliffUtilChangeBatchProcess: ^CG[܂Bob`𒆒f܂B:" + er.toString());
            er.printStackTrace();
            // ُIB
            return END_ERROR;
        }
    }

    /**
     * ̃ob`NX̎g̐Wo͂Ɏ߂̃\bhłB
     */
    public static final void usage() {
        System.out.println("BlancoXliffUtilChangeBatchProcess: Usage:");
        System.out.println("  java blanco.xliff.util.task.BlancoXliffUtilChangeBatchProcess -verbose=l1 -xliffdir=l2 -settargetifnotexist=l3");
        System.out.println("    -verbose");
        System.out.println("      [verbose[hœ삳邩ǂB]");
        System.out.println("      ^[^U]");
        System.out.println("      ftHgl[false]");
        System.out.println("    -xliffdir");
        System.out.println("      [XLIFF (*.xlf) fBNg]");
        System.out.println("      ^[]");
        System.out.println("      K{p[^");
        System.out.println("    -settargetifnotexist");
        System.out.println("      [target ꍇ target Zbg邩ǂB]");
        System.out.println("      ^[^U]");
        System.out.println("      ftHgl[false]");
        System.out.println("    -? , -help");
        System.out.println("      [g\܂B]");
    }

    /**
     * ̃ob`NX̓̓p[^̑Ó`FbN{邽߂̃\bhłB
     *
     * @param input ob`̓̓p[^B
     * @throws IllegalArgumentException ͒lɕsꍇB
     */
    public void validateInput(final BlancoXliffUtilChangeProcessInput input) throws IllegalArgumentException {
        if (input == null) {
            throw new IllegalArgumentException("BlancoBatchProcessBatchProcess: JnsB̓p[^[input]null^܂B");
        }
        if (input.getXliffdir() == null) {
            throw new IllegalArgumentException("BlancoXliffUtilChangeBatchProcess: JnsB̓p[^[input]̕K{tB[hl[xliffdir]ɒlݒ肳Ă܂B");
        }
    }
}
